Class: Google::Cloud::Dataform::V1::CommitLogEntry

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

Represents a single commit log.

Instance Attribute Summary collapse

Instance Attribute Details

#author ⇒ ::Google::Cloud::Dataform::V1::CommitAuthor

Returns The commit author for this commit log entry.

Returns:



511
512
513
514
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 511

class CommitLogEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#commit_message ⇒ ::String

Returns The commit message for this commit log entry.

Returns:

  • (::String) —

    The commit message for this commit log entry.



511
512
513
514
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 511

class CommitLogEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#commit_sha ⇒ ::String

Returns The commit SHA for this commit log entry.

Returns:

  • (::String) —

    The commit SHA for this commit log entry.



511
512
513
514
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 511

class CommitLogEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#commit_time ⇒ ::Google::Protobuf::Timestamp

Returns Commit timestamp.

Returns:



511
512
513
514
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 511

class CommitLogEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end