Class: Google::Cloud::Dataform::V1::CommitRepositoryChangesRequest::FileOperation
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::CommitRepositoryChangesRequest::FileOperation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
Represents a single file operation to the repository.
Defined Under Namespace
Classes: DeleteFile, WriteFile
Instance Attribute Summary collapse
-
#delete_file ⇒ ::Google::Cloud::Dataform::V1::CommitRepositoryChangesRequest::FileOperation::DeleteFile
Represents the delete operation.
-
#write_file ⇒ ::Google::Cloud::Dataform::V1::CommitRepositoryChangesRequest::FileOperation::WriteFile
Represents the write operation.
Instance Attribute Details
#delete_file ⇒ ::Google::Cloud::Dataform::V1::CommitRepositoryChangesRequest::FileOperation::DeleteFile
Returns Represents the delete operation.
Note: The following fields are mutually exclusive: delete_file, write_file. If a field in that set is populated, all other fields in the set will automatically be cleared.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 344 class FileOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the write file operation (for files added or modified). # @!attribute [rw] contents # @return [::String] # The file's contents. class WriteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the delete file operation. class DeleteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#write_file ⇒ ::Google::Cloud::Dataform::V1::CommitRepositoryChangesRequest::FileOperation::WriteFile
Returns Represents the write operation.
Note: The following fields are mutually exclusive: write_file, delete_file. If a field in that set is populated, all other fields in the set will automatically be cleared.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 344 class FileOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the write file operation (for files added or modified). # @!attribute [rw] contents # @return [::String] # The file's contents. class WriteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the delete file operation. class DeleteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |