Class: Google::Cloud::Dataform::V1::CommitWorkspaceChangesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

CommitWorkspaceChanges request message.

Instance Attribute Summary collapse

Instance Attribute Details

#author ⇒ ::Google::Cloud::Dataform::V1::CommitAuthor

Returns Required. The commit's author.

Returns:



838
839
840
841
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 838

class CommitWorkspaceChangesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#commit_message ⇒ ::String

Returns Optional. The commit's message.

Returns:

  • (::String) —

    Optional. The commit's message.



838
839
840
841
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 838

class CommitWorkspaceChangesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name ⇒ ::String

Returns Required. The workspace's name.

Returns:

  • (::String) —

    Required. The workspace's name.



838
839
840
841
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 838

class CommitWorkspaceChangesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#paths ⇒ ::Array<::String>

Returns Optional. Full file paths to commit including filename, rooted at workspace root. If left empty, all files will be committed.

Returns:

  • (::Array<::String>) —

    Optional. Full file paths to commit including filename, rooted at workspace root. If left empty, all files will be committed.



838
839
840
841
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 838

class CommitWorkspaceChangesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end