Class: Google::Cloud::Dataform::V1::CompilationResultAction::Assertion

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

Represents an assertion upon a SQL query which is required return zero rows.

Instance Attribute Summary collapse

Instance Attribute Details

#dependency_targets ⇒ ::Array<::Google::Cloud::Dataform::V1::Target>

Returns A list of actions that this action depends on.

Returns:



1966
1967
1968
1969
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1966

class Assertion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#disabled ⇒ ::Boolean

Returns Whether this action is disabled (i.e. should not be run).

Returns:

  • (::Boolean) —

    Whether this action is disabled (i.e. should not be run).



1966
1967
1968
1969
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1966

class Assertion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent_action ⇒ ::Google::Cloud::Dataform::V1::Target

Returns The parent action of this assertion. Only set if this assertion was automatically generated.

Returns:



1966
1967
1968
1969
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1966

class Assertion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#relation_descriptor ⇒ ::Google::Cloud::Dataform::V1::RelationDescriptor

Returns Descriptor for the assertion's automatically-generated view and its columns.

Returns:



1966
1967
1968
1969
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1966

class Assertion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#select_query ⇒ ::String

Returns The SELECT query which must return zero rows in order for this assertion to succeed.

Returns:

  • (::String) —

    The SELECT query which must return zero rows in order for this assertion to succeed.



1966
1967
1968
1969
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1966

class Assertion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tags ⇒ ::Array<::String>

Returns Arbitrary, user-defined tags on this action.

Returns:

  • (::Array<::String>) —

    Arbitrary, user-defined tags on this action.



1966
1967
1968
1969
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1966

class Assertion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end