Class: Google::Cloud::Dataform::V1::CompilationResultAction::Relation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

Represents a database relation.

Defined Under Namespace

Modules: FileFormat, RelationType, TableFormat Classes: AdditionalOptionsEntry, IncrementalTableConfig

Instance Attribute Summary collapse

Instance Attribute Details

#additional_options::Google::Protobuf::Map{::String => ::String}

Returns Additional options that will be provided as key/value pairs into the options clause of a create table/view statement. See https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language for more information on which options are supported.

Returns:



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#cluster_expressions::Array<::String>

Returns A list of columns or SQL expressions used to cluster the table.

Returns:

  • (::Array<::String>)

    A list of columns or SQL expressions used to cluster the table.



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#connection::String

Returns Optional. The connection specifying the credentials to be used to read and write to external storage, such as Cloud Storage. The connection can have the form {project}.{location}.{connection_id} or projects/{project}/locations/{location}/connections/{connection_id}, or be set to DEFAULT.

Returns:

  • (::String)

    Optional. The connection specifying the credentials to be used to read and write to external storage, such as Cloud Storage. The connection can have the form {project}.{location}.{connection_id} or projects/{project}/locations/{location}/connections/{connection_id}, or be set to DEFAULT.



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#dependency_targets::Array<::Google::Cloud::Dataform::V1::Target>

Returns A list of actions that this action depends on.

Returns:



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#disabled::Boolean

Returns Whether this action is disabled (i.e. should not be run).

Returns:

  • (::Boolean)

    Whether this action is disabled (i.e. should not be run).



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#file_format::Google::Cloud::Dataform::V1::CompilationResultAction::Relation::FileFormat

Returns Optional. The file format for the BigQuery table.

Returns:



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#incremental_table_config::Google::Cloud::Dataform::V1::CompilationResultAction::Relation::IncrementalTableConfig

Returns Configures INCREMENTAL_TABLE settings for this relation. Only set if relation_type is INCREMENTAL_TABLE.

Returns:



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#partition_expiration_days::Integer

Returns Sets the partition expiration in days.

Returns:

  • (::Integer)

    Sets the partition expiration in days.



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#partition_expression::String

Returns The SQL expression used to partition the relation.

Returns:

  • (::String)

    The SQL expression used to partition the relation.



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#post_operations::Array<::String>

Returns SQL statements to be executed after creating the relation.

Returns:

  • (::Array<::String>)

    SQL statements to be executed after creating the relation.



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#pre_operations::Array<::String>

Returns SQL statements to be executed before creating the relation.

Returns:

  • (::Array<::String>)

    SQL statements to be executed before creating the relation.



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#relation_descriptor::Google::Cloud::Dataform::V1::RelationDescriptor

Returns Descriptor for the relation and its columns.

Returns:



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#relation_type::Google::Cloud::Dataform::V1::CompilationResultAction::Relation::RelationType

Returns The type of this relation.



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#require_partition_filter::Boolean

Returns Specifies whether queries on this table must include a predicate filter that filters on the partitioning column.

Returns:

  • (::Boolean)

    Specifies whether queries on this table must include a predicate filter that filters on the partitioning column.



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#select_query::String

Returns The SELECT query which returns rows which this relation should contain.

Returns:

  • (::String)

    The SELECT query which returns rows which this relation should contain.



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#storage_uri::String

Returns Optional. The fully qualified location prefix of the external folder where table data is stored. The URI should be in the format gs://bucket/path_to_table/.

Returns:

  • (::String)

    Optional. The fully qualified location prefix of the external folder where table data is stored. The URI should be in the format gs://bucket/path_to_table/.



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#table_format::Google::Cloud::Dataform::V1::CompilationResultAction::Relation::TableFormat

Returns Optional. The table format for the BigQuery table.

Returns:



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#tags::Array<::String>

Returns Arbitrary, user-defined tags on this action.

Returns:

  • (::Array<::String>)

    Arbitrary, user-defined tags on this action.



1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1835

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end