Class: Google::Cloud::Dataform::V1::DeleteRepositoryRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::DeleteRepositoryRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
DeleteRepository request message.
Instance Attribute Summary collapse
-
#force ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#force ⇒ ::Boolean
Returns Optional. If set to true, child resources of this repository (compilation results and workflow invocations) will also be deleted. Otherwise, the request will only succeed if the repository has no child resources.
Note: This flag doesn't support deletion of workspaces, release configs or workflow configs. If any of such resources exists in the repository, the request will fail..
308 309 310 311 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 308 class DeleteRepositoryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The repository's name.
308 309 310 311 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 308 class DeleteRepositoryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |