Class: Google::Cloud::Dataform::V1::Folder

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

Represents a Dataform Folder. This is a resource that is used to organize Files and other Folders and provide hierarchical access controls.

Instance Attribute Summary collapse

Instance Attribute Details

#containing_folder::String

Returns Optional. The containing Folder resource name. This should take the format: projects/{project}/locations/{location}/folders/{folder}, projects/{project}/locations/{location}/teamFolders/{teamFolder}, or just projects/{project}/locations/{location} if this is a root Folder. This field can only be updated through MoveFolder.

Returns:

  • (::String)

    Optional. The containing Folder resource name. This should take the format: projects/{project}/locations/{location}/folders/{folder}, projects/{project}/locations/{location}/teamFolders/{teamFolder}, or just projects/{project}/locations/{location} if this is a root Folder. This field can only be updated through MoveFolder.



2733
2734
2735
2736
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2733

class Folder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp of when the Folder was created.

Returns:



2733
2734
2735
2736
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2733

class Folder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#creator_iam_principal::String (readonly)

Returns Output only. The IAM principal identifier of the creator of the Folder.

Returns:

  • (::String)

    Output only. The IAM principal identifier of the creator of the Folder.



2733
2734
2735
2736
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2733

class Folder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Required. The Folder's user-friendly name.

Returns:

  • (::String)

    Required. The Folder's user-friendly name.



2733
2734
2735
2736
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2733

class Folder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#internal_metadata::String (readonly)

Returns Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.

Returns:

  • (::String)

    Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.



2733
2734
2735
2736
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2733

class Folder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The Folder's name.

Returns:

  • (::String)

    Identifier. The Folder's name.



2733
2734
2735
2736
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2733

class Folder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#team_folder_name::String (readonly)

Returns Output only. The resource name of the TeamFolder that this Folder is associated with. This should take the format: projects/{project}/locations/{location}/teamFolders/{teamFolder}. If this is not set, the Folder is not associated with a TeamFolder and is a UserFolder.

Returns:

  • (::String)

    Output only. The resource name of the TeamFolder that this Folder is associated with. This should take the format: projects/{project}/locations/{location}/teamFolders/{teamFolder}. If this is not set, the Folder is not associated with a TeamFolder and is a UserFolder.



2733
2734
2735
2736
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2733

class Folder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp of when the Folder was last updated.

Returns:



2733
2734
2735
2736
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2733

class Folder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end