Class: Google::Cloud::Dataform::V1::GcsRepositorySnapshotDestination

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

Configures the destination for a repository snapshot.

Instance Attribute Summary collapse

Instance Attribute Details

#repository_snapshot_uri::String

Returns Optional. The Google Cloud Storage destination to upload the repository snapshot to. Format: gs://bucket-name/path/.

Returns:

  • (::String)

    Optional. The Google Cloud Storage destination to upload the repository snapshot to. Format: gs://bucket-name/path/.



1537
1538
1539
1540
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1537

class GcsRepositorySnapshotDestination
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end