Class: Google::Cloud::Dataform::V1::InvocationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::InvocationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
Includes various configuration options for a workflow invocation.
If both included_targets and included_tags are unset, all actions
will be included.
Defined Under Namespace
Modules: QueryPriority
Instance Attribute Summary collapse
-
#fully_refresh_incremental_tables_enabled ⇒ ::Boolean
Optional.
-
#included_tags ⇒ ::Array<::String>
Optional.
-
#included_targets ⇒ ::Array<::Google::Cloud::Dataform::V1::Target>
Optional.
-
#query_priority ⇒ ::Google::Cloud::Dataform::V1::InvocationConfig::QueryPriority
Optional.
-
#service_account ⇒ ::String
Optional.
-
#transitive_dependencies_included ⇒ ::Boolean
Optional.
-
#transitive_dependents_included ⇒ ::Boolean
Optional.
Instance Attribute Details
#fully_refresh_incremental_tables_enabled ⇒ ::Boolean
Returns Optional. When set to true, any incremental tables will be fully refreshed.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2163 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#included_tags ⇒ ::Array<::String>
Returns Optional. The set of tags to include.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2163 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#included_targets ⇒ ::Array<::Google::Cloud::Dataform::V1::Target>
Returns Optional. The set of action identifiers to include.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2163 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#query_priority ⇒ ::Google::Cloud::Dataform::V1::InvocationConfig::QueryPriority
Returns Optional. Specifies the priority for query execution in BigQuery. More information can be found at https://cloud.google.com/bigquery/docs/running-queries#queries.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2163 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#service_account ⇒ ::String
Returns Optional. The service account to run workflow invocations under.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2163 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#transitive_dependencies_included ⇒ ::Boolean
Returns Optional. When set to true, transitive dependencies of included actions will be executed.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2163 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#transitive_dependents_included ⇒ ::Boolean
Returns Optional. When set to true, transitive dependents of included actions will be executed.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2163 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |