Class: Google::Cloud::Dataform::V1::PipelineConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::PipelineConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
Defines the pipeline type and path within the Git repository.
Defined Under Namespace
Modules: PipelineType
Instance Attribute Summary collapse
-
#path ⇒ ::String
Required.
-
#pipeline_type ⇒ ::Google::Cloud::Dataform::V1::PipelineConfig::PipelineType
Required.
Instance Attribute Details
#path ⇒ ::String
Returns Required. The relative path within the Git repository where the pipeline is
defined. For example, for a Dataform pipeline, it is a path to the folder
where workflow_settings.yaml or dataform.json is located.
1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1572 class PipelineConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the pipeline. This may be extended in the future. # In case of UNSPECIFIED, the error will be thrown. module PipelineType # Default value. This value is unused. PIPELINE_TYPE_UNSPECIFIED = 0 # Regular Dataform pipeline. DATAFORM = 1 # SQL single file asset. SQL = 3 # Notebook single file asset. NOTEBOOK = 4 end end |
#pipeline_type ⇒ ::Google::Cloud::Dataform::V1::PipelineConfig::PipelineType
Returns Required. The type of the pipeline.
1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1572 class PipelineConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the pipeline. This may be extended in the future. # In case of UNSPECIFIED, the error will be thrown. module PipelineType # Default value. This value is unused. PIPELINE_TYPE_UNSPECIFIED = 0 # Regular Dataform pipeline. DATAFORM = 1 # SQL single file asset. SQL = 3 # Notebook single file asset. NOTEBOOK = 4 end end |