Class: Google::Cloud::Dataform::V1::PullGitCommitsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::PullGitCommitsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
PullGitCommits request message.
Instance Attribute Summary collapse
-
#author ⇒ ::Google::Cloud::Dataform::V1::CommitAuthor
Required.
-
#name ⇒ ::String
Required.
-
#remote_branch ⇒ ::String
Optional.
Instance Attribute Details
#author ⇒ ::Google::Cloud::Dataform::V1::CommitAuthor
Returns Required. The author of any merge commit which may be created as a result of merging fetched Git commits into this workspace.
718 719 720 721 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 718 class PullGitCommitsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The workspace's name.
718 719 720 721 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 718 class PullGitCommitsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#remote_branch ⇒ ::String
Returns Optional. The name of the branch in the Git remote from which to pull commits. If left unset, the repository's default branch name will be used.
718 719 720 721 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 718 class PullGitCommitsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |