Class: Google::Cloud::Dataform::V1::QueryFolderContentsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::QueryFolderContentsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
QueryFolderContents request message.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#folder ⇒ ::String
Required.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Optional filtering for the returned list. Filtering is currently
only supported on the display_name field.
Example:
filter="display_name="MyFolder"".
2913 2914 2915 2916 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2913 class QueryFolderContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#folder ⇒ ::String
Returns Required. Name of the folder whose contents to list. Format: projects//locations//folders/*.
2913 2914 2915 2916 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2913 class QueryFolderContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. Field to additionally sort results by.
Will order Folders before Repositories, and then by order_by in ascending
order. Supported keywords: display_name (default), create_time,
last_modified_time.
Examples:
orderBy="display_name"orderBy="display_name desc".
2913 2914 2915 2916 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2913 class QueryFolderContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.
2913 2914 2915 2916 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2913 class QueryFolderContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Page token received from a previous QueryFolderContents call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
QueryFolderContents, with the exception of page_size, must match the
call that provided the page token.
2913 2914 2915 2916 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2913 class QueryFolderContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |