Class: Google::Cloud::Dataform::V1::QueryRepositoryDirectoryContentsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

QueryRepositoryDirectoryContents response message.

Instance Attribute Summary collapse

Instance Attribute Details

#directory_entries::Array<::Google::Cloud::Dataform::V1::DirectoryEntry>

Returns List of entries in the directory.

Returns:



447
448
449
450
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 447

class QueryRepositoryDirectoryContentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



447
448
449
450
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 447

class QueryRepositoryDirectoryContentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end