Class: Google::Cloud::Dataform::V1::QueryTeamFolderContentsResponse::TeamFolderContentsEntry

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

Represents a single content entry.

Instance Attribute Summary collapse

Instance Attribute Details

#folder::Google::Cloud::Dataform::V1::Folder

Returns A subfolder.

Note: The following fields are mutually exclusive: folder, repository. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataform::V1::Folder)

    A subfolder.

    Note: The following fields are mutually exclusive: folder, repository. If a field in that set is populated, all other fields in the set will automatically be cleared.



3148
3149
3150
3151
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3148

class TeamFolderContentsEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#repository::Google::Cloud::Dataform::V1::Repository

Returns A repository.

Note: The following fields are mutually exclusive: repository, folder. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataform::V1::Repository)

    A repository.

    Note: The following fields are mutually exclusive: repository, folder. If a field in that set is populated, all other fields in the set will automatically be cleared.



3148
3149
3150
3151
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3148

class TeamFolderContentsEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end