Class: Google::Cloud::Dataform::V1::QueryUserRootContentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

QueryUserRootContents request message.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Optional filtering for the returned list. Filtering is currently only supported on the display_name field.

Example:

  • filter="display_name="MyFolder"".

Returns:

  • (::String)

    Optional. Optional filtering for the returned list. Filtering is currently only supported on the display_name field.

    Example:

    • filter="display_name="MyFolder""


2980
2981
2982
2983
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2980

class QueryUserRootContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location::String

Returns Required. Location of the user root folder whose contents to list. Format: projects//locations/.

Returns:

  • (::String)

    Required. Location of the user root folder whose contents to list. Format: projects//locations/



2980
2981
2982
2983
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2980

class QueryUserRootContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Field to additionally sort results by. Will order Folders before Repositories, and then by order_by in ascending order. Supported keywords: display_name (default), created_at, last_modified_at. Examples:

  • orderBy="display_name"
  • orderBy="display_name desc".

Returns:

  • (::String)

    Optional. Field to additionally sort results by. Will order Folders before Repositories, and then by order_by in ascending order. Supported keywords: display_name (default), created_at, last_modified_at. Examples:

    • orderBy="display_name"
    • orderBy="display_name desc"


2980
2981
2982
2983
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2980

class QueryUserRootContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.



2980
2981
2982
2983
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2980

class QueryUserRootContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Page token received from a previous QueryUserRootContents call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to QueryUserRootFolderContents, with the exception of page_size, must match the call that provided the page token.

Returns:

  • (::String)

    Optional. Page token received from a previous QueryUserRootContents call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to QueryUserRootFolderContents, with the exception of page_size, must match the call that provided the page token.



2980
2981
2982
2983
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2980

class QueryUserRootContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end