Class: Google::Cloud::Dataform::V1::RelationDescriptor

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

Describes a relation and its columns.

Defined Under Namespace

Classes: BigqueryLabelsEntry, ColumnDescriptor

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_labels::Google::Protobuf::Map{::String => ::String}

Returns A set of BigQuery labels that should be applied to the relation.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    A set of BigQuery labels that should be applied to the relation.



1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1688

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#columns::Array<::Google::Cloud::Dataform::V1::RelationDescriptor::ColumnDescriptor>

Returns A list of descriptions of columns within the relation.

Returns:



1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1688

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns A text description of the relation.

Returns:

  • (::String)

    A text description of the relation.



1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1688

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end