Class: Google::Cloud::Dataform::V1::RelationDescriptor::ColumnDescriptor

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

Describes a column.

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_policy_tags ⇒ ::Array<::String>

Returns A list of BigQuery policy tags that will be applied to the column.

Returns:

  • (::Array<::String>) —

    A list of BigQuery policy tags that will be applied to the column.



1703
1704
1705
1706
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1703

class ColumnDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description ⇒ ::String

Returns A textual description of the column.

Returns:

  • (::String) —

    A textual description of the column.



1703
1704
1705
1706
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1703

class ColumnDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path ⇒ ::Array<::String>

Returns The identifier for the column. Each entry in path represents one level of nesting.

Returns:

  • (::Array<::String>) —

    The identifier for the column. Each entry in path represents one level of nesting.



1703
1704
1705
1706
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1703

class ColumnDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end