Class: Google::Cloud::Dataform::V1::Repository::GitRemoteSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::Repository::GitRemoteSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
Controls Git remote configuration for a repository.
Defined Under Namespace
Modules: TokenStatus Classes: SshAuthenticationConfig
Instance Attribute Summary collapse
-
#authentication_token_secret_version ⇒ ::String
Optional.
-
#default_branch ⇒ ::String
Required.
-
#ssh_authentication_config ⇒ ::Google::Cloud::Dataform::V1::Repository::GitRemoteSettings::SshAuthenticationConfig
Optional.
-
#token_status ⇒ ::Google::Cloud::Dataform::V1::Repository::GitRemoteSettings::TokenStatus
readonly
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#url ⇒ ::String
Required.
Instance Attribute Details
#authentication_token_secret_version ⇒ ::String
Returns Optional. The name of the Secret Manager secret version to use as an
authentication token for Git operations. Must be in the format
projects/*/secrets/*/versions/*.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 122 class GitRemoteSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configures fields for performing SSH authentication. # @!attribute [rw] user_private_key_secret_version # @return [::String] # Required. The name of the Secret Manager secret version to use as a # ssh private key for Git operations. # Must be in the format `projects/*/secrets/*/versions/*`. # @!attribute [rw] host_public_key # @return [::String] # Required. Content of a public SSH key to verify an identity of a remote # Git host. class SshAuthenticationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The status of the authentication token. module TokenStatus # Default value. This value is unused. TOKEN_STATUS_UNSPECIFIED = 0 # The token could not be found in Secret Manager (or the Dataform # Service Account did not have permission to access it). NOT_FOUND = 1 # The token could not be used to authenticate against the Git remote. INVALID = 2 # The token was used successfully to authenticate against the Git remote. VALID = 3 end end |
#default_branch ⇒ ::String
Returns Required. The Git remote's default branch name.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 122 class GitRemoteSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configures fields for performing SSH authentication. # @!attribute [rw] user_private_key_secret_version # @return [::String] # Required. The name of the Secret Manager secret version to use as a # ssh private key for Git operations. # Must be in the format `projects/*/secrets/*/versions/*`. # @!attribute [rw] host_public_key # @return [::String] # Required. Content of a public SSH key to verify an identity of a remote # Git host. class SshAuthenticationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The status of the authentication token. module TokenStatus # Default value. This value is unused. TOKEN_STATUS_UNSPECIFIED = 0 # The token could not be found in Secret Manager (or the Dataform # Service Account did not have permission to access it). NOT_FOUND = 1 # The token could not be used to authenticate against the Git remote. INVALID = 2 # The token was used successfully to authenticate against the Git remote. VALID = 3 end end |
#ssh_authentication_config ⇒ ::Google::Cloud::Dataform::V1::Repository::GitRemoteSettings::SshAuthenticationConfig
Returns Optional. Authentication fields for remote uris using SSH protocol.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 122 class GitRemoteSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configures fields for performing SSH authentication. # @!attribute [rw] user_private_key_secret_version # @return [::String] # Required. The name of the Secret Manager secret version to use as a # ssh private key for Git operations. # Must be in the format `projects/*/secrets/*/versions/*`. # @!attribute [rw] host_public_key # @return [::String] # Required. Content of a public SSH key to verify an identity of a remote # Git host. class SshAuthenticationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The status of the authentication token. module TokenStatus # Default value. This value is unused. TOKEN_STATUS_UNSPECIFIED = 0 # The token could not be found in Secret Manager (or the Dataform # Service Account did not have permission to access it). NOT_FOUND = 1 # The token could not be used to authenticate against the Git remote. INVALID = 2 # The token was used successfully to authenticate against the Git remote. VALID = 3 end end |
#token_status ⇒ ::Google::Cloud::Dataform::V1::Repository::GitRemoteSettings::TokenStatus (readonly)
This field is deprecated and may be removed in the next major version update.
Returns Output only. Deprecated: The field does not contain any token status information.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 122 class GitRemoteSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configures fields for performing SSH authentication. # @!attribute [rw] user_private_key_secret_version # @return [::String] # Required. The name of the Secret Manager secret version to use as a # ssh private key for Git operations. # Must be in the format `projects/*/secrets/*/versions/*`. # @!attribute [rw] host_public_key # @return [::String] # Required. Content of a public SSH key to verify an identity of a remote # Git host. class SshAuthenticationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The status of the authentication token. module TokenStatus # Default value. This value is unused. TOKEN_STATUS_UNSPECIFIED = 0 # The token could not be found in Secret Manager (or the Dataform # Service Account did not have permission to access it). NOT_FOUND = 1 # The token could not be used to authenticate against the Git remote. INVALID = 2 # The token was used successfully to authenticate against the Git remote. VALID = 3 end end |
#url ⇒ ::String
Returns Required. The Git remote's URL.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 122 class GitRemoteSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configures fields for performing SSH authentication. # @!attribute [rw] user_private_key_secret_version # @return [::String] # Required. The name of the Secret Manager secret version to use as a # ssh private key for Git operations. # Must be in the format `projects/*/secrets/*/versions/*`. # @!attribute [rw] host_public_key # @return [::String] # Required. Content of a public SSH key to verify an identity of a remote # Git host. class SshAuthenticationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The status of the authentication token. module TokenStatus # Default value. This value is unused. TOKEN_STATUS_UNSPECIFIED = 0 # The token could not be found in Secret Manager (or the Dataform # Service Account did not have permission to access it). NOT_FOUND = 1 # The token could not be used to authenticate against the Git remote. INVALID = 2 # The token was used successfully to authenticate against the Git remote. VALID = 3 end end |