Class: Google::Cloud::Dataform::V1::TeamFolder

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

Represents a Dataform TeamFolder. This is a resource that sits at the project level and is used to organize Repositories and Folders with hierarchical access controls. They provide a team context and stricter access controls.

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp of when the TeamFolder was created.

Returns:



3037
3038
3039
3040
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3037

class TeamFolder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#creator_iam_principal::String (readonly)

Returns Output only. The IAM principal identifier of the creator of the TeamFolder.

Returns:

  • (::String)

    Output only. The IAM principal identifier of the creator of the TeamFolder.



3037
3038
3039
3040
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3037

class TeamFolder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Required. The TeamFolder's user-friendly name.

Returns:

  • (::String)

    Required. The TeamFolder's user-friendly name.



3037
3038
3039
3040
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3037

class TeamFolder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#internal_metadata::String (readonly)

Returns Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.

Returns:

  • (::String)

    Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.



3037
3038
3039
3040
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3037

class TeamFolder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The TeamFolder's name.

Returns:

  • (::String)

    Identifier. The TeamFolder's name.



3037
3038
3039
3040
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3037

class TeamFolder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp of when the TeamFolder was last updated.

Returns:



3037
3038
3039
3040
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3037

class TeamFolder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end