Class: Google::Cloud::Dataform::V1::CompilationResultAction::DataPreparation
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::CompilationResultAction::DataPreparation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
Defines a compiled Data Preparation entity
Defined Under Namespace
Classes: ErrorTable, SqlDefinition
Instance Attribute Summary collapse
-
#contents_sql ⇒ ::Google::Cloud::Dataform::V1::CompilationResultAction::DataPreparation::SqlDefinition
SQL definition for a Data Preparation.
-
#contents_yaml ⇒ ::String
The data preparation definition, stored as a YAML string.
-
#dependency_targets ⇒ ::Array<::Google::Cloud::Dataform::V1::Target>
A list of actions that this action depends on.
-
#disabled ⇒ ::Boolean
Whether this action is disabled (i.e. should not be run).
-
#tags ⇒ ::Array<::String>
Arbitrary, user-defined tags on this action.
Instance Attribute Details
#contents_sql ⇒ ::Google::Cloud::Dataform::V1::CompilationResultAction::DataPreparation::SqlDefinition
Returns SQL definition for a Data Preparation. Contains a SQL query and additional context information.
Note: The following fields are mutually exclusive: contents_sql, contents_yaml. If a field in that set is populated, all other fields in the set will automatically be cleared.
1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1934 class DataPreparation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1::CompilationResultAction::DataPreparation::ErrorTable] # Error table configuration, # @!attribute [rw] load # @return [::Google::Cloud::Dataform::V1::CompilationResultAction::LoadConfig] # Load configuration. class SqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#contents_yaml ⇒ ::String
Returns The data preparation definition, stored as a YAML string.
Note: The following fields are mutually exclusive: contents_yaml, contents_sql. If a field in that set is populated, all other fields in the set will automatically be cleared.
1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1934 class DataPreparation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1::CompilationResultAction::DataPreparation::ErrorTable] # Error table configuration, # @!attribute [rw] load # @return [::Google::Cloud::Dataform::V1::CompilationResultAction::LoadConfig] # Load configuration. class SqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#dependency_targets ⇒ ::Array<::Google::Cloud::Dataform::V1::Target>
Returns A list of actions that this action depends on.
1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1934 class DataPreparation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1::CompilationResultAction::DataPreparation::ErrorTable] # Error table configuration, # @!attribute [rw] load # @return [::Google::Cloud::Dataform::V1::CompilationResultAction::LoadConfig] # Load configuration. class SqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#disabled ⇒ ::Boolean
Returns Whether this action is disabled (i.e. should not be run).
1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1934 class DataPreparation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1::CompilationResultAction::DataPreparation::ErrorTable] # Error table configuration, # @!attribute [rw] load # @return [::Google::Cloud::Dataform::V1::CompilationResultAction::LoadConfig] # Load configuration. class SqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tags ⇒ ::Array<::String>
Returns Arbitrary, user-defined tags on this action.
1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1934 class DataPreparation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1::CompilationResultAction::DataPreparation::ErrorTable] # Error table configuration, # @!attribute [rw] load # @return [::Google::Cloud::Dataform::V1::CompilationResultAction::LoadConfig] # Load configuration. class SqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |