Class: Google::Cloud::Dataform::V1::CompilationResultAction::Relation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

Represents a database relation.

Defined Under Namespace

Modules: FileFormat, RelationType, TableFormat Classes: AdditionalOptionsEntry, IncrementalTableConfig

Instance Attribute Summary collapse

Instance Attribute Details

#additional_options::Google::Protobuf::Map{::String => ::String}

Returns Additional options that will be provided as key/value pairs into the options clause of a create table/view statement. See https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language for more information on which options are supported.

Returns:



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#cluster_expressions::Array<::String>

Returns A list of columns or SQL expressions used to cluster the table.

Returns:

  • (::Array<::String>)

    A list of columns or SQL expressions used to cluster the table.



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#connection::String

Returns Optional. The connection specifying the credentials to be used to read and write to external storage, such as Cloud Storage. The connection can have the form {project}.{location}.{connection_id} or projects/{project}/locations/{location}/connections/{connection_id}, or be set to DEFAULT.

Returns:

  • (::String)

    Optional. The connection specifying the credentials to be used to read and write to external storage, such as Cloud Storage. The connection can have the form {project}.{location}.{connection_id} or projects/{project}/locations/{location}/connections/{connection_id}, or be set to DEFAULT.



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#dependency_targets::Array<::Google::Cloud::Dataform::V1::Target>

Returns A list of actions that this action depends on.

Returns:



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#disabled::Boolean

Returns Whether this action is disabled (i.e. should not be run).

Returns:

  • (::Boolean)

    Whether this action is disabled (i.e. should not be run).



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#file_format::Google::Cloud::Dataform::V1::CompilationResultAction::Relation::FileFormat

Returns Optional. The file format for the BigQuery table.

Returns:



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#incremental_table_config::Google::Cloud::Dataform::V1::CompilationResultAction::Relation::IncrementalTableConfig

Returns Configures INCREMENTAL_TABLE settings for this relation. Only set if relation_type is INCREMENTAL_TABLE.

Returns:



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#partition_expiration_days::Integer

Returns Sets the partition expiration in days.

Returns:

  • (::Integer)

    Sets the partition expiration in days.



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#partition_expression::String

Returns The SQL expression used to partition the relation.

Returns:

  • (::String)

    The SQL expression used to partition the relation.



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#post_operations::Array<::String>

Returns SQL statements to be executed after creating the relation.

Returns:

  • (::Array<::String>)

    SQL statements to be executed after creating the relation.



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#pre_operations::Array<::String>

Returns SQL statements to be executed before creating the relation.

Returns:

  • (::Array<::String>)

    SQL statements to be executed before creating the relation.



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#relation_descriptor::Google::Cloud::Dataform::V1::RelationDescriptor

Returns Descriptor for the relation and its columns.

Returns:



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#relation_type::Google::Cloud::Dataform::V1::CompilationResultAction::Relation::RelationType

Returns The type of this relation.



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#require_partition_filter::Boolean

Returns Specifies whether queries on this table must include a predicate filter that filters on the partitioning column.

Returns:

  • (::Boolean)

    Specifies whether queries on this table must include a predicate filter that filters on the partitioning column.



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#select_query::String

Returns The SELECT query which returns rows which this relation should contain.

Returns:

  • (::String)

    The SELECT query which returns rows which this relation should contain.



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#storage_uri::String

Returns Optional. The fully qualified location prefix of the external folder where table data is stored. The URI should be in the format gs://bucket/path_to_table/.

Returns:

  • (::String)

    Optional. The fully qualified location prefix of the external folder where table data is stored. The URI should be in the format gs://bucket/path_to_table/.



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#table_format::Google::Cloud::Dataform::V1::CompilationResultAction::Relation::TableFormat

Returns Optional. The table format for the BigQuery table.

Returns:



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end

#tags::Array<::String>

Returns Arbitrary, user-defined tags on this action.

Returns:

  • (::Array<::String>)

    Arbitrary, user-defined tags on this action.



1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1748

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end

  # Supported table formats for BigQuery tables.
  module TableFormat
    # Default value.
    TABLE_FORMAT_UNSPECIFIED = 0

    # Apache Iceberg format.
    ICEBERG = 1
  end

  # Supported file formats for BigQuery tables.
  module FileFormat
    # Default value.
    FILE_FORMAT_UNSPECIFIED = 0

    # Apache Parquet format.
    PARQUET = 1
  end
end