Class: Google::Cloud::Dataform::V1::ComputeRepositoryAccessTokenStatusResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

ComputeRepositoryAccessTokenStatus response message.

Defined Under Namespace

Modules: TokenStatus

Instance Attribute Summary collapse

Instance Attribute Details

#token_status::Google::Cloud::Dataform::V1::ComputeRepositoryAccessTokenStatusResponse::TokenStatus

Returns Indicates the status of the Git access token.

Returns:



530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 530

class ComputeRepositoryAccessTokenStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the status of a Git authentication token.
  module TokenStatus
    # Default value. This value is unused.
    TOKEN_STATUS_UNSPECIFIED = 0

    # The token could not be found in Secret Manager (or the Dataform
    # Service Account did not have permission to access it).
    NOT_FOUND = 1

    # The token could not be used to authenticate against the Git remote.
    INVALID = 2

    # The token was used successfully to authenticate against the Git remote.
    VALID = 3

    # The token is not accessible due to permission issues.
    PERMISSION_DENIED = 4
  end
end