Class: Google::Cloud::Dataform::V1::DeleteFolderTreeMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::DeleteFolderTreeMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
Contains metadata about the progress of the DeleteFolderTree Long-running operations.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#percent_complete ⇒ ::Integer
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Dataform::V1::DeleteFolderTreeMetadata::State
readonly
Output only.
-
#target ⇒ ::String
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the operation was created.
2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2855 class DeleteFolderTreeMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteFolderTree operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation was initialized and recorded by the server, but not yet # started. INITIALIZED = 1 # The operation is in progress. IN_PROGRESS = 2 # The operation has completed successfully. SUCCEEDED = 3 # The operation has failed. FAILED = 4 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the operation finished running.
2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2855 class DeleteFolderTreeMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteFolderTree operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation was initialized and recorded by the server, but not yet # started. INITIALIZED = 1 # The operation is in progress. IN_PROGRESS = 2 # The operation has completed successfully. SUCCEEDED = 3 # The operation has failed. FAILED = 4 end end |
#percent_complete ⇒ ::Integer (readonly)
Returns Output only. Percent complete of the operation [0, 100].
2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2855 class DeleteFolderTreeMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteFolderTree operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation was initialized and recorded by the server, but not yet # started. INITIALIZED = 1 # The operation is in progress. IN_PROGRESS = 2 # The operation has completed successfully. SUCCEEDED = 3 # The operation has failed. FAILED = 4 end end |
#state ⇒ ::Google::Cloud::Dataform::V1::DeleteFolderTreeMetadata::State (readonly)
Returns Output only. The state of the operation.
2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2855 class DeleteFolderTreeMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteFolderTree operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation was initialized and recorded by the server, but not yet # started. INITIALIZED = 1 # The operation is in progress. IN_PROGRESS = 2 # The operation has completed successfully. SUCCEEDED = 3 # The operation has failed. FAILED = 4 end end |
#target ⇒ ::String (readonly)
Returns Output only. Resource name of the target of the operation. Format: projects/{project}/locations/{location}/folders/{folder} or projects/{project}/locations/{location}/teamFolders/{team_folder}.
2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2855 class DeleteFolderTreeMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteFolderTree operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation was initialized and recorded by the server, but not yet # started. INITIALIZED = 1 # The operation is in progress. IN_PROGRESS = 2 # The operation has completed successfully. SUCCEEDED = 3 # The operation has failed. FAILED = 4 end end |