Class: Google::Cloud::Dataform::V1::DeleteFolderTreeRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::DeleteFolderTreeRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
DeleteFolderTree request message.
Instance Attribute Summary collapse
-
#force ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#force ⇒ ::Boolean
Returns Optional. If false (default): The operation will fail if any
Repository within the folder hierarchy has associated Release Configs or
Workflow Configs.
If true: The operation will attempt to delete everything, including any
Release Configs and Workflow Configs linked to Repositories within the
folder hierarchy. This permanently removes schedules and resources.
2907 2908 2909 2910 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2907 class DeleteFolderTreeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The Folder's name. Format: projects/{project}/locations/{location}/folders/{folder}.
2907 2908 2909 2910 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2907 class DeleteFolderTreeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |