Class: Google::Cloud::Dataform::V1::DeleteFolderTreeRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

DeleteFolderTree request message.

Instance Attribute Summary collapse

Instance Attribute Details

#force::Boolean

Returns Optional. If false (default): The operation will fail if any Repository within the folder hierarchy has associated Release Configs or Workflow Configs.

If true: The operation will attempt to delete everything, including any Release Configs and Workflow Configs linked to Repositories within the folder hierarchy. This permanently removes schedules and resources.

Returns:

  • (::Boolean)

    Optional. If false (default): The operation will fail if any Repository within the folder hierarchy has associated Release Configs or Workflow Configs.

    If true: The operation will attempt to delete everything, including any Release Configs and Workflow Configs linked to Repositories within the folder hierarchy. This permanently removes schedules and resources.



2826
2827
2828
2829
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2826

class DeleteFolderTreeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The Folder's name. Format: projects/{project}/locations/{location}/folders/{folder}.

Returns:

  • (::String)

    Required. The Folder's name. Format: projects/{project}/locations/{location}/folders/{folder}



2826
2827
2828
2829
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2826

class DeleteFolderTreeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end