Class: Google::Cloud::Dataform::V1::FilesystemEntryMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::FilesystemEntryMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
Represents metadata for a single entry in a filesystem.
Instance Attribute Summary collapse
-
#size_bytes ⇒ ::Integer
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#size_bytes ⇒ ::Integer (readonly)
Returns Output only. Provides the size of the entry in bytes. For directories, this will be 0.
954 955 956 957 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 954 class FilesystemEntryMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Represents the time of the last modification of the entry.
954 955 956 957 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 954 class FilesystemEntryMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |