Class: Google::Cloud::Dataform::V1::MoveRepositoryMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

Contains metadata about the progress of the MoveRepository Long-running operations.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the operation was created.

Returns:



3270
3271
3272
3273
3274
3275
3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
3287
3288
3289
3290
3291
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3270

class MoveRepositoryMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the move.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The move was initialized and recorded by the server, but not yet started.
    INITIALIZED = 1

    # The move is in progress.
    IN_PROGRESS = 2

    # The move has completed successfully.
    SUCCESS = 3

    # The move has failed.
    FAILED = 4
  end
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the operation finished running.

Returns:



3270
3271
3272
3273
3274
3275
3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
3287
3288
3289
3290
3291
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3270

class MoveRepositoryMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the move.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The move was initialized and recorded by the server, but not yet started.
    INITIALIZED = 1

    # The move is in progress.
    IN_PROGRESS = 2

    # The move has completed successfully.
    SUCCESS = 3

    # The move has failed.
    FAILED = 4
  end
end

#percent_complete::Integer

Returns Percent complete of the move [0, 100].

Returns:

  • (::Integer)

    Percent complete of the move [0, 100].



3270
3271
3272
3273
3274
3275
3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
3287
3288
3289
3290
3291
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3270

class MoveRepositoryMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the move.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The move was initialized and recorded by the server, but not yet started.
    INITIALIZED = 1

    # The move is in progress.
    IN_PROGRESS = 2

    # The move has completed successfully.
    SUCCESS = 3

    # The move has failed.
    FAILED = 4
  end
end

#state::Google::Cloud::Dataform::V1::MoveRepositoryMetadata::State

Returns The state of the move.

Returns:



3270
3271
3272
3273
3274
3275
3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
3287
3288
3289
3290
3291
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3270

class MoveRepositoryMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the move.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The move was initialized and recorded by the server, but not yet started.
    INITIALIZED = 1

    # The move is in progress.
    IN_PROGRESS = 2

    # The move has completed successfully.
    SUCCESS = 3

    # The move has failed.
    FAILED = 4
  end
end

#target::String (readonly)

Returns Output only. Server-defined resource path for the target of the operation.

Returns:

  • (::String)

    Output only. Server-defined resource path for the target of the operation.



3270
3271
3272
3273
3274
3275
3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
3287
3288
3289
3290
3291
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3270

class MoveRepositoryMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the move.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The move was initialized and recorded by the server, but not yet started.
    INITIALIZED = 1

    # The move is in progress.
    IN_PROGRESS = 2

    # The move has completed successfully.
    SUCCESS = 3

    # The move has failed.
    FAILED = 4
  end
end