Class: Google::Cloud::Dataform::V1::QueryFolderContentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::QueryFolderContentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
QueryFolderContents response message.
Defined Under Namespace
Classes: FolderContentsEntry
Instance Attribute Summary collapse
-
#entries ⇒ ::Array<::Google::Cloud::Dataform::V1::QueryFolderContentsResponse::FolderContentsEntry>
List of entries in the folder.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#entries ⇒ ::Array<::Google::Cloud::Dataform::V1::QueryFolderContentsResponse::FolderContentsEntry>
Returns List of entries in the folder.
3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3023 class QueryFolderContentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single content entry. # @!attribute [rw] folder # @return [::Google::Cloud::Dataform::V1::Folder] # A subfolder. # # Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] repository # @return [::Google::Cloud::Dataform::V1::Repository] # A repository. # # Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared. class FolderContentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3023 class QueryFolderContentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single content entry. # @!attribute [rw] folder # @return [::Google::Cloud::Dataform::V1::Folder] # A subfolder. # # Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] repository # @return [::Google::Cloud::Dataform::V1::Repository] # A repository. # # Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared. class FolderContentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |