Class: Google::Cloud::Dataform::V1::QueryTeamFolderContentsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1/dataform.rb

Overview

QueryTeamFolderContents response message.

Defined Under Namespace

Classes: TeamFolderContentsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#entries ⇒ ::Array<::Google::Cloud::Dataform::V1::QueryTeamFolderContentsResponse::TeamFolderContentsEntry>



3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
3168
3169
3170
3171
3172
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3153

class QueryTeamFolderContentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a single content entry.
  # @!attribute [rw] folder
  #   @return [::Google::Cloud::Dataform::V1::Folder]
  #     A subfolder.
  #
  #     Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] repository
  #   @return [::Google::Cloud::Dataform::V1::Repository]
  #     A repository.
  #
  #     Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class TeamFolderContentsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token ⇒ ::String



3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
3168
3169
3170
3171
3172
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 3153

class QueryTeamFolderContentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a single content entry.
  # @!attribute [rw] folder
  #   @return [::Google::Cloud::Dataform::V1::Folder]
  #     A subfolder.
  #
  #     Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] repository
  #   @return [::Google::Cloud::Dataform::V1::Repository]
  #     A repository.
  #
  #     Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class TeamFolderContentsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end