Class: Google::Cloud::Dataform::V1::QueryUserRootContentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::QueryUserRootContentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
QueryUserRootContents response message.
Defined Under Namespace
Classes: RootContentsEntry
Instance Attribute Summary collapse
-
#entries ⇒ ::Array<::Google::Cloud::Dataform::V1::QueryUserRootContentsResponse::RootContentsEntry>
List of entries in the folder.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#entries ⇒ ::Array<::Google::Cloud::Dataform::V1::QueryUserRootContentsResponse::RootContentsEntry>
Returns List of entries in the folder.
2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2993 class QueryUserRootContentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single content entry. # @!attribute [rw] folder # @return [::Google::Cloud::Dataform::V1::Folder] # A subfolder. # # Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] repository # @return [::Google::Cloud::Dataform::V1::Repository] # A repository. # # Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared. class RootContentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2993 class QueryUserRootContentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single content entry. # @!attribute [rw] folder # @return [::Google::Cloud::Dataform::V1::Folder] # A subfolder. # # Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] repository # @return [::Google::Cloud::Dataform::V1::Repository] # A repository. # # Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared. class RootContentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |