Class: Google::Cloud::Dataform::V1::RelationDescriptor
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::RelationDescriptor
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
Describes a relation and its columns.
Defined Under Namespace
Classes: BigqueryLabelsEntry, ColumnDescriptor
Instance Attribute Summary collapse
-
#bigquery_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
A set of BigQuery labels that should be applied to the relation.
-
#columns ⇒ ::Array<::Google::Cloud::Dataform::V1::RelationDescriptor::ColumnDescriptor>
A list of descriptions of columns within the relation.
-
#description ⇒ ::String
A text description of the relation.
Instance Attribute Details
#bigquery_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns A set of BigQuery labels that should be applied to the relation.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1601 class RelationDescriptor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a column. # @!attribute [rw] path # @return [::Array<::String>] # The identifier for the column. Each entry in `path` represents one level # of nesting. # @!attribute [rw] description # @return [::String] # A textual description of the column. # @!attribute [rw] bigquery_policy_tags # @return [::Array<::String>] # A list of BigQuery policy tags that will be applied to the column. class ColumnDescriptor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class BigqueryLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#columns ⇒ ::Array<::Google::Cloud::Dataform::V1::RelationDescriptor::ColumnDescriptor>
Returns A list of descriptions of columns within the relation.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1601 class RelationDescriptor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a column. # @!attribute [rw] path # @return [::Array<::String>] # The identifier for the column. Each entry in `path` represents one level # of nesting. # @!attribute [rw] description # @return [::String] # A textual description of the column. # @!attribute [rw] bigquery_policy_tags # @return [::Array<::String>] # A list of BigQuery policy tags that will be applied to the column. class ColumnDescriptor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class BigqueryLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns A text description of the relation.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 1601 class RelationDescriptor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a column. # @!attribute [rw] path # @return [::Array<::String>] # The identifier for the column. Each entry in `path` represents one level # of nesting. # @!attribute [rw] description # @return [::String] # A textual description of the column. # @!attribute [rw] bigquery_policy_tags # @return [::Array<::String>] # A list of BigQuery policy tags that will be applied to the column. class ColumnDescriptor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class BigqueryLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |