Class: Google::Cloud::Dataform::V1::WorkflowConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::WorkflowConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
Represents a Dataform workflow configuration.
Defined Under Namespace
Classes: ScheduledExecutionRecord
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#cron_schedule ⇒ ::String
Optional.
-
#disabled ⇒ ::Boolean
Optional.
-
#internal_metadata ⇒ ::String
readonly
Output only.
-
#invocation_config ⇒ ::Google::Cloud::Dataform::V1::InvocationConfig
Optional.
-
#name ⇒ ::String
Identifier.
-
#recent_scheduled_execution_records ⇒ ::Array<::Google::Cloud::Dataform::V1::WorkflowConfig::ScheduledExecutionRecord>
readonly
Output only.
-
#release_config ⇒ ::String
Required.
-
#time_zone ⇒ ::String
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of when the WorkflowConfig was created.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2094 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] execution_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this execution attempt. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#cron_schedule ⇒ ::String
Returns Optional. Optional schedule (in cron format) for automatic execution of this workflow config.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2094 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] execution_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this execution attempt. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#disabled ⇒ ::Boolean
Returns Optional. Disables automatic creation of workflow invocations.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2094 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] execution_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this execution attempt. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#internal_metadata ⇒ ::String (readonly)
Returns Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2094 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] execution_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this execution attempt. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#invocation_config ⇒ ::Google::Cloud::Dataform::V1::InvocationConfig
Returns Optional. If left unset, a default InvocationConfig will be used.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2094 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] execution_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this execution attempt. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The workflow config's name.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2094 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] execution_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this execution attempt. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#recent_scheduled_execution_records ⇒ ::Array<::Google::Cloud::Dataform::V1::WorkflowConfig::ScheduledExecutionRecord> (readonly)
Returns Output only. Records of the 10 most recent scheduled execution attempts,
ordered in descending order of execution_time. Updated whenever automatic
creation of a workflow invocation is triggered by cron_schedule.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2094 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] execution_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this execution attempt. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#release_config ⇒ ::String
Returns Required. The name of the release config whose release_compilation_result
should be executed. Must be in the format
projects/*/locations/*/repositories/*/releaseConfigs/*.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2094 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] execution_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this execution attempt. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#time_zone ⇒ ::String
Returns Optional. Specifies the time zone to be used when interpreting cron_schedule. Must be a time zone name from the time zone database (https://en.wikipedia.org/wiki/List_of_tz_database_time_zones). If left unspecified, the default is UTC.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2094 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] execution_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this execution attempt. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of when the WorkflowConfig was last updated.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2094 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] execution_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this execution attempt. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |