Class: Google::Cloud::Dataform::V1::WorkflowInvocation
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::WorkflowInvocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
Represents a single invocation of a compilation result.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#compilation_result ⇒ ::String
Immutable.
-
#data_encryption_state ⇒ ::Google::Cloud::Dataform::V1::DataEncryptionState
readonly
Output only.
-
#internal_metadata ⇒ ::String
readonly
Output only.
-
#invocation_config ⇒ ::Google::Cloud::Dataform::V1::InvocationConfig
Immutable.
-
#invocation_timing ⇒ ::Google::Type::Interval
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#private_resource_metadata ⇒ ::Google::Cloud::Dataform::V1::PrivateResourceMetadata
readonly
Output only.
-
#resolved_compilation_result ⇒ ::String
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Dataform::V1::WorkflowInvocation::State
readonly
Output only.
-
#workflow_config ⇒ ::String
Immutable.
Instance Attribute Details
#compilation_result ⇒ ::String
Returns Immutable. The name of the compilation result to use for this invocation.
Must be in the format
projects/*/locations/*/repositories/*/compilationResults/*.
Note: The following fields are mutually exclusive: compilation_result, workflow_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2302 class WorkflowInvocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the current state of a workflow invocation. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The workflow invocation is currently running. RUNNING = 1 # The workflow invocation succeeded. A terminal state. SUCCEEDED = 2 # The workflow invocation was cancelled. A terminal state. CANCELLED = 3 # The workflow invocation failed. A terminal state. FAILED = 4 # The workflow invocation is being cancelled, but some actions are still # running. CANCELING = 5 end end |
#data_encryption_state ⇒ ::Google::Cloud::Dataform::V1::DataEncryptionState (readonly)
Returns Output only. Only set if the repository has a KMS Key.
2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2302 class WorkflowInvocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the current state of a workflow invocation. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The workflow invocation is currently running. RUNNING = 1 # The workflow invocation succeeded. A terminal state. SUCCEEDED = 2 # The workflow invocation was cancelled. A terminal state. CANCELLED = 3 # The workflow invocation failed. A terminal state. FAILED = 4 # The workflow invocation is being cancelled, but some actions are still # running. CANCELING = 5 end end |
#internal_metadata ⇒ ::String (readonly)
Returns Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2302 class WorkflowInvocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the current state of a workflow invocation. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The workflow invocation is currently running. RUNNING = 1 # The workflow invocation succeeded. A terminal state. SUCCEEDED = 2 # The workflow invocation was cancelled. A terminal state. CANCELLED = 3 # The workflow invocation failed. A terminal state. FAILED = 4 # The workflow invocation is being cancelled, but some actions are still # running. CANCELING = 5 end end |
#invocation_config ⇒ ::Google::Cloud::Dataform::V1::InvocationConfig
Returns Immutable. If left unset, a default InvocationConfig will be used.
2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2302 class WorkflowInvocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the current state of a workflow invocation. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The workflow invocation is currently running. RUNNING = 1 # The workflow invocation succeeded. A terminal state. SUCCEEDED = 2 # The workflow invocation was cancelled. A terminal state. CANCELLED = 3 # The workflow invocation failed. A terminal state. FAILED = 4 # The workflow invocation is being cancelled, but some actions are still # running. CANCELING = 5 end end |
#invocation_timing ⇒ ::Google::Type::Interval (readonly)
Returns Output only. This workflow invocation's timing details.
2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2302 class WorkflowInvocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the current state of a workflow invocation. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The workflow invocation is currently running. RUNNING = 1 # The workflow invocation succeeded. A terminal state. SUCCEEDED = 2 # The workflow invocation was cancelled. A terminal state. CANCELLED = 3 # The workflow invocation failed. A terminal state. FAILED = 4 # The workflow invocation is being cancelled, but some actions are still # running. CANCELING = 5 end end |
#name ⇒ ::String (readonly)
Returns Output only. The workflow invocation's name.
2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2302 class WorkflowInvocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the current state of a workflow invocation. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The workflow invocation is currently running. RUNNING = 1 # The workflow invocation succeeded. A terminal state. SUCCEEDED = 2 # The workflow invocation was cancelled. A terminal state. CANCELLED = 3 # The workflow invocation failed. A terminal state. FAILED = 4 # The workflow invocation is being cancelled, but some actions are still # running. CANCELING = 5 end end |
#private_resource_metadata ⇒ ::Google::Cloud::Dataform::V1::PrivateResourceMetadata (readonly)
Returns Output only. Metadata indicating whether this resource is user-scoped.
WorkflowInvocation resource is user_scoped only if it is sourced
from a compilation result and the compilation result is user-scoped.
2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2302 class WorkflowInvocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the current state of a workflow invocation. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The workflow invocation is currently running. RUNNING = 1 # The workflow invocation succeeded. A terminal state. SUCCEEDED = 2 # The workflow invocation was cancelled. A terminal state. CANCELLED = 3 # The workflow invocation failed. A terminal state. FAILED = 4 # The workflow invocation is being cancelled, but some actions are still # running. CANCELING = 5 end end |
#resolved_compilation_result ⇒ ::String (readonly)
Returns Output only. The resolved compilation result that was used to create this
invocation. Will be in the format
projects/*/locations/*/repositories/*/compilationResults/*.
2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2302 class WorkflowInvocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the current state of a workflow invocation. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The workflow invocation is currently running. RUNNING = 1 # The workflow invocation succeeded. A terminal state. SUCCEEDED = 2 # The workflow invocation was cancelled. A terminal state. CANCELLED = 3 # The workflow invocation failed. A terminal state. FAILED = 4 # The workflow invocation is being cancelled, but some actions are still # running. CANCELING = 5 end end |
#state ⇒ ::Google::Cloud::Dataform::V1::WorkflowInvocation::State (readonly)
Returns Output only. This workflow invocation's current state.
2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2302 class WorkflowInvocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the current state of a workflow invocation. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The workflow invocation is currently running. RUNNING = 1 # The workflow invocation succeeded. A terminal state. SUCCEEDED = 2 # The workflow invocation was cancelled. A terminal state. CANCELLED = 3 # The workflow invocation failed. A terminal state. FAILED = 4 # The workflow invocation is being cancelled, but some actions are still # running. CANCELING = 5 end end |
#workflow_config ⇒ ::String
Returns Immutable. The name of the workflow config to invoke. Must be in the
format projects/*/locations/*/repositories/*/workflowConfigs/*.
Note: The following fields are mutually exclusive: workflow_config, compilation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2302 class WorkflowInvocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the current state of a workflow invocation. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The workflow invocation is currently running. RUNNING = 1 # The workflow invocation succeeded. A terminal state. SUCCEEDED = 2 # The workflow invocation was cancelled. A terminal state. CANCELLED = 3 # The workflow invocation failed. A terminal state. FAILED = 4 # The workflow invocation is being cancelled, but some actions are still # running. CANCELING = 5 end end |