Class: Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1/dataform.rb
Overview
Represents a workflow action that will run a Data Preparation.
Defined Under Namespace
Classes: ActionErrorTable, ActionIncrementalLoadMode, ActionLoadConfig, ActionSimpleLoadMode, ActionSqlDefinition
Instance Attribute Summary collapse
-
#contents_sql ⇒ ::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionSqlDefinition
SQL definition for a Data Preparation.
-
#contents_yaml ⇒ ::String
readonly
Output only.
-
#generated_sql ⇒ ::String
readonly
Output only.
-
#job_id ⇒ ::String
readonly
Output only.
Instance Attribute Details
#contents_sql ⇒ ::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionSqlDefinition
Returns SQL definition for a Data Preparation. Contains a SQL query and additional context information.
Note: The following fields are mutually exclusive: contents_sql, contents_yaml. If a field in that set is populated, all other fields in the set will automatically be cleared.
2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2612 class DataPreparationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionErrorTable] # Error table configuration, # @!attribute [rw] load_config # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionLoadConfig] # Load configuration. class ActionSqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ActionErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simplified load configuration for actions # @!attribute [rw] replace # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Replace destination table # # Note: The following fields are mutually exclusive: `replace`, `append`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] append # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Append into destination table # # Note: The following fields are mutually exclusive: `append`, `replace`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] maximum # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value exceeds the previous maximum value for # a column in the destination table # # Note: The following fields are mutually exclusive: `maximum`, `replace`, `append`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] unique # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value of a column is not already present in # the destination table # # Note: The following fields are mutually exclusive: `unique`, `replace`, `append`, `maximum`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ActionLoadConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simple load definition class ActionSimpleLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Load definition for incremental load modes # @!attribute [rw] column # @return [::String] # Column name for incremental load modes class ActionIncrementalLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#contents_yaml ⇒ ::String (readonly)
Returns Output only. YAML representing the contents of the data preparation. Can be used to show the customer what the input was to their workflow.
Note: The following fields are mutually exclusive: contents_yaml, contents_sql. If a field in that set is populated, all other fields in the set will automatically be cleared.
2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2612 class DataPreparationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionErrorTable] # Error table configuration, # @!attribute [rw] load_config # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionLoadConfig] # Load configuration. class ActionSqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ActionErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simplified load configuration for actions # @!attribute [rw] replace # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Replace destination table # # Note: The following fields are mutually exclusive: `replace`, `append`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] append # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Append into destination table # # Note: The following fields are mutually exclusive: `append`, `replace`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] maximum # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value exceeds the previous maximum value for # a column in the destination table # # Note: The following fields are mutually exclusive: `maximum`, `replace`, `append`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] unique # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value of a column is not already present in # the destination table # # Note: The following fields are mutually exclusive: `unique`, `replace`, `append`, `maximum`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ActionLoadConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simple load definition class ActionSimpleLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Load definition for incremental load modes # @!attribute [rw] column # @return [::String] # Column name for incremental load modes class ActionIncrementalLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#generated_sql ⇒ ::String (readonly)
Returns Output only. The generated BigQuery SQL script that will be executed. For reference only.
2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2612 class DataPreparationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionErrorTable] # Error table configuration, # @!attribute [rw] load_config # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionLoadConfig] # Load configuration. class ActionSqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ActionErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simplified load configuration for actions # @!attribute [rw] replace # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Replace destination table # # Note: The following fields are mutually exclusive: `replace`, `append`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] append # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Append into destination table # # Note: The following fields are mutually exclusive: `append`, `replace`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] maximum # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value exceeds the previous maximum value for # a column in the destination table # # Note: The following fields are mutually exclusive: `maximum`, `replace`, `append`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] unique # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value of a column is not already present in # the destination table # # Note: The following fields are mutually exclusive: `unique`, `replace`, `append`, `maximum`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ActionLoadConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simple load definition class ActionSimpleLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Load definition for incremental load modes # @!attribute [rw] column # @return [::String] # Column name for incremental load modes class ActionIncrementalLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#job_id ⇒ ::String (readonly)
Returns Output only. The ID of the BigQuery job that executed the SQL in sql_script. Only set once the job has started to run.
2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 |
# File 'proto_docs/google/cloud/dataform/v1/dataform.rb', line 2612 class DataPreparationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionErrorTable] # Error table configuration, # @!attribute [rw] load_config # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionLoadConfig] # Load configuration. class ActionSqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ActionErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simplified load configuration for actions # @!attribute [rw] replace # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Replace destination table # # Note: The following fields are mutually exclusive: `replace`, `append`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] append # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Append into destination table # # Note: The following fields are mutually exclusive: `append`, `replace`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] maximum # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value exceeds the previous maximum value for # a column in the destination table # # Note: The following fields are mutually exclusive: `maximum`, `replace`, `append`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] unique # @return [::Google::Cloud::Dataform::V1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value of a column is not already present in # the destination table # # Note: The following fields are mutually exclusive: `unique`, `replace`, `append`, `maximum`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ActionLoadConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simple load definition class ActionSimpleLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Load definition for incremental load modes # @!attribute [rw] column # @return [::String] # Column name for incremental load modes class ActionIncrementalLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |